# AWS CDK CloudFormation Constructs for Symphonia::OpenSource::CloudFormationArtifactsBucket::MODULE

Schema for Module Fragment of type Symphonia::OpenSource::CloudFormationArtifactsBucket::MODULE

## License

Distributed under the Apache-2.0 License.
